@@ -1,4 +1,5 @@
 import datetime as dt
+from copy import deepcopy
 from pathlib import Path
 from typing import List, Optional, Union
 
@@ -37,6 +38,7 @@ class Config:
     slug: str
     spec: AnalysisSpec
     last_modified: dt.datetime
+    is_private: bool = False
 
     def validate(self, configs: "ConfigCollection", experiment: Experiment) -> None:
         spec = AnalysisSpec.default_for_experiment(experiment, configs)
@@ -121,6 +123,7 @@ class Outcome:
     spec: OutcomeSpec
     platform: str
     commit_hash: Optional[str]
+    is_private: bool = False
 
     def validate(self, configs: "ConfigCollection") -> None:
         dummy_experiment = Experiment(
@@ -149,7 +152,7 @@ class DefinitionConfig(Config):
     Represents an definition config file with definition that can be referenced in other configs.
     """
 
-    platform: str
+    platform: str = "firefox_desktop"
 
     def validate(self, configs: "ConfigCollection", _experiment: Experiment = None) -> None:
         dummy_experiment = Experiment(
@@ -219,22 +222,29 @@ class ConfigCollection:
     repo_url = "https://github.com/mozilla/jetstream-config"
 
     @classmethod
-    def from_github_repo(cls) -> "ConfigCollection":
+    def from_github_repo(
+        cls, repo_url: Optional[str] = None, is_private: bool = False
+    ) -> "ConfigCollection":
         """Pull in external config files."""
         # download files to tmp directory
         with TemporaryDirectory() as tmp_dir:
-            repo = Repo.clone_from(cls.repo_url, tmp_dir)
+            repo = Repo.clone_from(repo_url or cls.repo_url, tmp_dir)
 
             external_configs = []
 
             for config_file in tmp_dir.glob("*.toml"):
                 last_modified = next(repo.iter_commits("main", paths=config_file)).committed_date
+                analysis_spec = AnalysisSpec.from_dict(toml.load(config_file))
+                analysis_spec.experiment.is_private = (
+                    analysis_spec.experiment.is_private or is_private
+                )
 
                 external_configs.append(
                     Config(
                         config_file.stem,
-                        AnalysisSpec.from_dict(toml.load(config_file)),
+                        analysis_spec,
                         UTC.localize(dt.datetime.utcfromtimestamp(last_modified)),
+                        is_private=is_private,
                     )
                 )
 
@@ -248,6 +258,7 @@ class ConfigCollection:
                         spec=OutcomeSpec.from_dict(toml.load(outcome_file)),
                         platform=outcome_file.parent.name,
                         commit_hash=commit_hash,
+                        is_private=is_private,
                     )
                 )
 
@@ -262,6 +273,7 @@ class ConfigCollection:
                         default_config_file.stem,
                         AnalysisSpec.from_dict(toml.load(default_config_file)),
                         UTC.localize(dt.datetime.utcfromtimestamp(last_modified)),
+                        is_private=is_private,
                     )
                 )
 
@@ -277,6 +289,7 @@ class ConfigCollection:
                         AnalysisSpec.from_dict(toml.load(definitions_config_file)),
                         UTC.localize(dt.datetime.utcfromtimestamp(last_modified)),
                         platform=definitions_config_file.stem,
+                        is_private=is_private,
                     )
                 )
 
@@ -286,6 +299,24 @@ class ConfigCollection:
 
         return cls(external_configs, outcomes, default_configs, definitions, functions_spec)
 
+    @classmethod
+    def from_github_repos(
+        cls, repo_urls: Optional[List[str]] = None, is_private: bool = False
+    ) -> "ConfigCollection":
+        """Load configs from the provided repos."""
+        if repo_urls is None or len(repo_urls) > 0:
+            return ConfigCollection.from_github_repo()
+
+        configs = None
+        for repo in repo_urls:
+            if configs is None:
+                configs = ConfigCollection.from_github_repo(repo, is_private=is_private)
+            else:
+                collection = ConfigCollection.from_github_repo(repo, is_private=is_private)
+                configs.merge(collection)
+
+        return configs or ConfigCollection.from_github_repo()
+
     def spec_for_outcome(self, slug: str, platform: str) -> Optional[OutcomeSpec]:
         """Return the spec for a specific outcome"""
         for outcome in self.outcomes:
@@ -365,3 +396,66 @@ class ConfigCollection:
                 env.globals[slug] = function.definition
 
         return env
+
+    def merge(self, other: "ConfigCollection"):
+        """
+        Merge this config collection with another.
+
+        Configs in `other` will take precedence.
+        """
+        # merge configs
+        other_configs = {config.slug: config for config in deepcopy(other.configs)}
+        configs = {config.slug: config for config in deepcopy(self.configs)}
+
+        for slug, config in other_configs.items():
+            if slug not in configs:
+                configs[slug] = config
+            else:
+                configs[slug].spec.merge(config.spec)
+
+        self.configs = list(configs.values())
+
+        # merge outcomes
+        outcomes = deepcopy(other.outcomes)
+        slugs = [outcome.slug for outcome in outcomes]
+        for outcome in self.outcomes:
+            if outcome.slug not in slugs:
+                outcomes.append(outcome)
+
+        # merge definitions
+        other_definitions = {
+            definition.slug: definition for definition in deepcopy(other.definitions)
+        }
+        definitions = {definition.slug: definition for definition in deepcopy(self.definitions)}
+
+        for slug, definition in other_definitions.items():
+            if slug not in definitions:
+                definitions[slug] = definition
+            else:
+                definitions[slug].spec.merge(definition.spec)
+
+        self.definitions = list(definitions.values())
+
+        # merge defaults
+        other_defaults = {default.slug: default for default in deepcopy(other.defaults)}
+        defaults = {default.slug: default for default in deepcopy(self.defaults)}
+
+        for slug, default in other_defaults.items():
+            if slug not in defaults:
+                defaults[slug] = default
+            else:
+                defaults[slug].spec.merge(default.spec)
+
+        self.defaults = list(defaults.values())
+
+        # merge functions
+        functions = deepcopy(other.functions.functions) if other.functions else {}
+        slugs = [slug for slug, _ in functions.items()]
+        for slug, function in self.functions.functions.items() if self.functions else {}:
+            if slug not in slugs:
+                functions[slug] = function
+
+        if self.functions is None:
+            self.functions = FunctionsSpec(functions=functions)
+        else:
+            self.functions.functions = functions
